//    Copyright (c) 2021 Grigor Hakobyan <grighakobian@gmail.com>
//
//    Permission is hereby granted, free of charge, to any person obtaining a copy
//    of this software and associated documentation files (the "Software"), to deal
//    in the Software without restriction, including without limitation the rights
//    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//    copies of the Software, and to permit persons to whom the Software is
//    furnished to do so, subject to the following conditions:
//
//    The above copyright notice and this permission notice shall be included in
//    all copies or substantial portions of the Software.
//
//    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//    THE SOFTWARE.

public struct ScrollDirection: OptionSet {
    
    /// Scroll direction right.
    public static let right = ScrollDirection(rawValue: 1 << 0)
    
    /// Scroll direction left.
    public static let left = ScrollDirection(rawValue: 1 << 1)
    
    /// Scroll direction up.
    public static let up = ScrollDirection(rawValue: 1 << 2)
    
    /// Scroll direction down.
    public static let down = ScrollDirection(rawValue: 1 << 3)
    
    /// The horizontal scroll direction.
    public static let horizontal: ScrollDirection = [.left, .right]
    
    /// The vertical scroll direction.
    public static let vertical: ScrollDirection = [.up, .down]
    
    public let rawValue: Int8
    
    public init(rawValue: Int8) {
        self.rawValue = rawValue
    }
    
}
